Crate unsync_pipe

Crate unsync_pipe 

Single-threaded binary safe AsyncWrite/AsyncRead pair

The main entry point is pipe. Writer and Reader can just be sent across binary boundaries. A change to the ABI constitutes a major version break.

Structs

Reader
A binary safe AsyncRead implementor reading from a ringbuffer created by pipe
Writer
A binary safe AsyncWrite implementor writing to a ringbuffer created by pipe.

Functions

pipe
Create a ringbuffer with the specified byte capacity. Once the buffer is exhausted, the writer will block.